@@ -412,27 +412,29 @@ class CalcDataFrame(object):
                 # 从高净值跌到低净值
                 per_retracement: pd.Series = 1 - per_data[swanav_column] / per_data[swanav_column].expanding(
                     min_periods=1).max()
-                edate = per_retracement.idxmax()
-                max_retracement = per_retracement[edate]
-                max_net = per_data[:edate][swanav_column].max()
-                max_net_data = per_data[per_data[swanav_column] >= max_net]
-                bdate = max_net_data[max_net_data.index < edate].index.max()
-                rdate = max_net_data[max_net_data.index > edate].index.min()
-                rdays = (rdate - edate).days
+                if len(per_retracement) != 0:
+                    edate = per_retracement.idxmax()
+                    max_retracement = per_retracement[edate]
+                    max_net = per_data[:edate][swanav_column].max()
+                    max_net_data = per_data[per_data[swanav_column] >= max_net]
+                    bdate = max_net_data[max_net_data.index < edate].index.max()
+                    rdate = max_net_data[max_net_data.index > edate].index.min()
+                    rdays = (rdate - edate).days
             elif method == 'MD':
                 per_data.sort_index(ascending=False, inplace=True)
                 per_retracement: pd.Series = per_data[swanav_column].expanding(min_periods=1).min() / per_data[
                     swanav_column] - 1
                 per_data.sort_index(ascending=True, inplace=True)
-                bdate = per_retracement.idxmin()
-                max_retracement = per_retracement[bdate]
-                min_net = per_data[bdate:][swanav_column].min()
-                min_net_data = per_data[per_data[swanav_column] <= min_net]
-                edate = min_net_data[min_net_data.index > bdate].index.min()
-                max_net = per_data[per_data.index == bdate][swanav_column].max()
-                max_net_data = per_data[per_data[swanav_column] >= max_net]
-                rdate = max_net_data[max_net_data.index > edate].index.min()
-                rdays = (rdate - edate).days
+                if len(per_retracement) != 0:
+                    bdate = per_retracement.idxmin()
+                    max_retracement = per_retracement[bdate]
+                    min_net = per_data[bdate:][swanav_column].min()
+                    min_net_data = per_data[per_data[swanav_column] <= min_net]
+                    edate = min_net_data[min_net_data.index > bdate].index.min()
+                    max_net = per_data[per_data.index == bdate][swanav_column].max()
+                    max_net_data = per_data[per_data[swanav_column] >= max_net]
+                    rdate = max_net_data[max_net_data.index > edate].index.min()
+                    rdays = (rdate - edate).days
             else:
                 raise BizException('最大回撤method错误,MF或MD')
         result[period + suffix] = max_retracement
@@ -656,7 +658,7 @@ class CalcDataFrame(object):
                                  direction=direction)
         if fund_colunm == market_colunm:
             fund_colunm = fund_colunm + '_x'
-            market_colunm = fund_colunm + '_y'
+            market_colunm = market_colunm + '_y'
         cal_data = fund_ret[start_date:end_date]
         if isinstance(period, str):
             period = [period]
@@ -709,6 +711,7 @@ class CalcDataFrame(object):
         nrr:
             无风险收益率，默认取中国银行一年定期利率0.0175
         """
+        fund_ret_a = fund_ret_a.copy()
         fund_ret_a['temp_colunm'] = 1
         mg_data = pd.merge_asof(fund_ret_a['temp_colunm'], market_ret_a, left_index=True, right_index=True,
                                 direction=direction).drop(columns=['temp_colunm'])
